<?php

namespace Drupal\cards\Plugin\Field\FieldWidget;





use Drupal\entityreference_view_mode\Plugin\Field\FieldWidget\EntityReferenceViewModeFieldWidgetTrait;

trait CardWidgetTrait {

  use EntityReferenceViewModeFieldWidgetTrait;

  public function cardOptions($items,
                              $delta,
                              $element,
                              &$form,
                              $form_state) {


    // Figure out what has been selected in the widget so far.
    $selections = $this->getSelections($items, $delta, $element, $form, $form_state);

    // If no view mode is selected then dont add the card options.
    if (empty($selections['view_mode'])) {
      return $element;
    }

    // Build some context to pass to the alter functions
    $context = [
      'items' => $items,
      'delta' => $delta,
      'element' => $element,
      'form' => $form,
      'form_state' => $form_state,
      'target_type' => $selections['target_type'],
      'view_mode' => $selections['view_mode'],
      'content' => $selections['content'],
      'bundle' => $selections['target_type'],
    ];

    // Add ajax to view mode
    $element['view_mode'] += [  '#ajax' => [
      'callback' => [$this, 'updateWidgetOptions'],
      'wrapper' => $element['content']['#ajax']['wrapper'],
      'method' => 'replace',
      'progress' => [
          'type' => 'throbber',
      ],
    ]];

    $width_options = $this->getFieldSetting('settings')[$selections['target_type']]['widths'];
    \Drupal::moduleHandler()->alter('widths', $width_options, $context);

    $card_group_1_options = $this->getFieldSetting('settings')[$selections['target_type']]['group_1'];
    \Drupal::moduleHandler()->alter('card_group_1', $card_group_1_options, $context);

    $card_group_2_options = $this->getFieldSetting('settings')[$selections['target_type']]['group_2'];
    \Drupal::moduleHandler()->alter('card_group_2', $card_group_2_options, $context);

    $card_group_3_options = $this->getFieldSetting('settings')[$selections['target_type']]['group_3'];
    \Drupal::moduleHandler()->alter('card_group_3', $card_group_3_options, $context);

    $card_group_4_options = $this->getFieldSetting('settings')[$selections['target_type']]['group_4'];
    \Drupal::moduleHandler()->alter('card_group_4', $card_group_4_options, $context);

    $adhoc_options = $this->getFieldSetting('settings')[$selections['target_type']]['adhoc'];
    \Drupal::moduleHandler()->alter('card_adhoc', $adhoc_options, $context);


    $widths = isset($items[$delta]->widths) ? $items[$delta]->widths : '';
    if (count($width_options)) {
      $element['widths'] = [
        '#type' => 'select',
        '#title' => t('widths'),
        '#title_display' => 'hidden',
        '#default_value' => $widths,
        '#options' => $width_options,
      ];

    }
    else {
      // Hidden color field.
      $element['widths'] = [
        '#type' => 'hidden',
        '#default_value' => '',
      ];
    }


    $group_1 = isset($items[$delta]->group_1) ? $items[$delta]->group_1 : '';
    if (count($card_group_1_options)) {
      $element['group_1'] = [
        '#type' => 'select',
        '#title' => t('group_1'),
        '#title_display' => 'hidden',
        '#default_value' => $group_1,
        '#options' => $card_group_1_options,
      ];

    }
    else {
      // Hidden color field.
      $element['group_1'] = [
        '#type' => 'hidden',
        '#default_value' => '',
      ];
    }

    $group_2 = isset($items[$delta]->group_2) ? $items[$delta]->group_2 : '';

    if (count($card_group_2_options)) {

      // Width.
      $element['group_2'] = [
        '#type' => 'select',
        '#title' => t('group_2'),
        '#title_display' => 'hidden',
        '#default_value' => $group_2,
        '#options' => $card_group_2_options,
      ];

    }
    else {
      // Hidden width field.
      $element['group_2'] = [
        '#type' => 'hidden',
        '#default_value' => '',
      ];

    }

    $group_3 = isset($items[$delta]->group_3) ? $items[$delta]->group_3 : '';

    if (count($card_group_3_options)) {

      // Height.
      $element['group_3'] = [
        '#type' => 'select',
        '#title' => t('group_3'),
        '#title_display' => 'hidden',
        '#default_value' => $group_3,
        '#options' => $card_group_3_options,
      ];
    }
    else {

      // Hidden height field.
      $element['group_3'] = [
        '#type' => 'hidden',
        '#default_value' => '',
      ];
    }

    $group_4 = isset($items[$delta]->group_4) ? $items[$delta]->group_4 : '';

    if (count($card_group_4_options)) {

      // Height.
      $element['group_4'] = [
        '#type' => 'select',
        '#title' => t('group_4'),
        '#title_display' => 'hidden',
        '#default_value' => $group_4,
        '#options' => $card_group_4_options,
      ];
    }
    else {

      // Hidden icon field.
      $element['group_4'] = [
        '#type' => 'hidden',
        '#default_value' => '',
      ];
    }

    $classes = isset($items[$delta]->adhoc) ? $items[$delta]->adhoc : [];
    $element['adhoc'] = [
      '#type' => 'checkboxes',
      '#title_display' => 'attribute',
      '#default_value' => $classes,
      '#options' => $adhoc_options,
    ];
    return $element;
  }
}

